@@ -9,10 +9,8 @@ import (
 )
 
 func init() {
-	lang.GoFunctions["read"] = cmdRead
-	//lang.DefineMethod("read", cmdRead, types.String, types.Null)
-	lang.GoFunctions["tread"] = cmdTread
-	//lang.DefineMethod("tread", cmdTread, types.String, types.Null)
+	lang.DefineMethod("read", cmdRead, types.String, types.Null)
+	lang.DefineMethod("tread", cmdTread, types.String, types.Null)
 }
 
 func cmdRead(p *lang.Process) error {
@@ -31,7 +29,7 @@ func read(p *lang.Process, dt string, paramAdjust int) error {
 	p.Stdout.SetDataType(types.Null)
 
 	if p.Background.Get() {
-		return errors.New("Background processes cannot read from stdin")
+		return errors.New("background processes cannot read from stdin")
 	}
 
 	var prompt string
