@@ -1,13 +1,11 @@
+//go:build windows
 // +build windows
 
 package autocomplete
 
 import (
-	"io/ioutil"
 	"strings"
 
-	"github.com/lmorg/murex/lang"
-	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/utils/consts"
 )
 
@@ -17,39 +15,10 @@ func SplitPath(envPath string) []string {
 	return split
 }
 
+// listExes called listExesWindows which exists in execs.go because it needs to
+// be called when murex runs inside WSL
 func listExes(path string, exes map[string]bool) {
-	var showExts bool
-
-	v, err := lang.ShellProcess.Config.Get("shell", "extensions-enabled", types.Boolean)
-	if err != nil {
-		showExts = false
-	} else {
-		showExts = v.(bool)
-	}
-
-	files, _ := ioutil.ReadDir(path)
-	for _, f := range files {
-		if f.IsDir() {
-			continue
-		}
-
-		name := strings.ToLower(f.Name())
-
-		if len(name) < 5 {
-			continue
-		}
-
-		ext := name[len(name)-4:]
-
-		if ext == ".exe" || ext == ".com" || ext == ".bat" || ext == ".cmd" || ext == ".scr" {
-			if showExts {
-				exes[name] = true
-			} else {
-				exes[name[:len(name)-4]] = true
-			}
-		}
-	}
-	return
+	listExesWindows(path, exes)
 }
 
 func matchExes(s string, exes map[string]bool, includeColon bool) (items []string) {
@@ -72,7 +41,5 @@ func matchExes(s string, exes map[string]bool, includeColon bool) (items []strin
 		}
 	}
 
-	//sortColon(items, 0, len(items)-1)
-
 	return
 }
