@@ -26,6 +26,7 @@ var safeCmds = []string{
 	"bexists",
 	"cast",
 	"catch",
+	"count",
 	"cpuarch",
 	"cpucount",
 	"debug",
@@ -50,7 +51,6 @@ var safeCmds = []string{
 	"ja",
 	"jsplit",
 	"left",
-	"len",
 	"man-summary",
 	"map",
 	"match",
