@@ -75,6 +75,12 @@ type Instance struct {
 	// then readline will just use the current line.
 	GetMultiLine func([]rune) []rune
 
+	MaxCacheSize int
+	cacheHint    cacheSliceRune
+	cacheSyntax  cacheString
+	//cacheSyntaxHighlight cacheString
+	//cacheSyntaxDelayed   cacheSliceRune
+
 	// readline operating parameters
 	prompt        string //  = ">>> "
 	promptLen     int    //= 4
@@ -146,5 +152,9 @@ func NewInstance() *Instance {
 
 	//rl.EnableGetCursorPos = true
 
+	rl.MaxCacheSize = 256
+	rl.cacheHint.Init(rl)
+	rl.cacheSyntax.Init(rl)
+
 	return rl
 }
